dab

package module
v0.0.0-...-8ca8fd0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 21, 2018 License: MIT Imports: 8 Imported by: 0

README

dab

Tool to apply anonymity enhancements to popular browser

Browser Patching

Documentation

Index

Constants

const Name = "untraceable"
const VersionStr = "0.1.0-1" // SemVer

Variables

var (
	// ErrNotFound is returned when an value or idx is not in the database.
	ErrNotFound = errors.New("not found")

	// ErrInvalid is returned when the database file is an invalid format.
	ErrInvalid = errors.New("invalid")
)
var GIT = ""
var Logger = CLILogger()
var Path = ""
var Version semver.Version

Functions

func CLILogger

func CLILogger() zerolog.Logger

func DaemonLogger

func DaemonLogger(dev bool) zerolog.Logger

Types

This section is empty.

Directories

Path Synopsis
assets
logo
GENERATED
GENERATED
Command simple is a chromedp example demonstrating how to do a simple google search.
Command simple is a chromedp example demonstrating how to do a simple google search.
cmd
agent command
app command
host command
launcher command

Jump to