Documentation
¶
Index ¶
Constants ¶
const Name = "untraceable"
const VersionStr = "0.1.0-1" // SemVer
Variables ¶
var ( // ErrNotFound is returned when an value or idx is not in the database. ErrNotFound = errors.New("not found") // ErrInvalid is returned when the database file is an invalid format. ErrInvalid = errors.New("invalid") )
var GIT = ""
var Logger = CLILogger()
var Metrics = metrics.DefaultRegistry
var Path = ""
var Version semver.Version
Functions ¶
func DaemonLogger ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.